@@ -14,10 +14,12 @@
 # Copyright (c) 2018 Daniel Colascione <dancol@dancol.org>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 doranid <ddandd@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 
 """This module contains base classes and functions for the nodes and some
 inference utils.
@@ -26,7 +28,7 @@ inference utils.
 import collections
 
 from astroid import context as contextmod
-from astroid import util
+from astroid import decorators, util
 from astroid.const import BUILTINS, PY310_PLUS
 from astroid.exceptions import (
     AstroidTypeError,
@@ -541,12 +543,16 @@ class Generator(BaseInstance):
     Proxied class is set once for all in raw_building.
     """
 
-    # pylint: disable=unnecessary-lambda
-    special_attributes = util.lazy_descriptor(lambda: objectmodel.GeneratorModel())
+    special_attributes = util.lazy_descriptor(objectmodel.GeneratorModel)
 
-    # pylint: disable=super-init-not-called
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, generator_initial_context=None):
+        super().__init__()
         self.parent = parent
+        self._call_context = contextmod.copy_context(generator_initial_context)
+
+    @decorators.cached
+    def infer_yield_types(self):
+        yield from self.parent.infer_yield_result(self._call_context)
 
     def callable(self):
         return False
@@ -566,7 +572,7 @@ class Generator(BaseInstance):
         )
 
     def __str__(self):
-        return "Generator(%s)" % (self._proxied.name)
+        return "Generator(%s)" % self._proxied.name
 
 
 class AsyncGenerator(Generator):
@@ -584,4 +590,4 @@ class AsyncGenerator(Generator):
         )
 
     def __str__(self):
-        return "AsyncGenerator(%s)" % (self._proxied.name)
+        return "AsyncGenerator(%s)" % self._proxied.name
