@@ -7,7 +7,7 @@ Without this hook pylint reports unsupported-assignment-operation
 for attrs classes
 """
 from astroid.manager import AstroidManager
-from astroid.node_classes import AnnAssign, Assign, Call, Unknown
+from astroid.node_classes import AnnAssign, Assign, AssignName, Call, Unknown
 from astroid.scoped_nodes import ClassDef
 
 ATTRIB_NAMES = frozenset(("attr.ib", "attrib", "attr.attrib"))
@@ -27,7 +27,7 @@ def is_decorated_with_attrs(node, decorator_names=ATTRS_NAMES):
     return False
 
 
-def attr_attributes_transform(node):
+def attr_attributes_transform(node: ClassDef) -> None:
     """Given that the ClassNode has an attr decorator,
     rewrite class attributes as instance attributes
     """
@@ -35,28 +35,31 @@ def attr_attributes_transform(node):
     # Prevents https://github.com/PyCQA/pylint/issues/1884
     node.locals["__attrs_attrs__"] = [Unknown(parent=node)]
 
-    for cdefbodynode in node.body:
-        if not isinstance(cdefbodynode, (Assign, AnnAssign)):
+    for cdef_body_node in node.body:
+        if not isinstance(cdef_body_node, (Assign, AnnAssign)):
             continue
-        if isinstance(cdefbodynode.value, Call):
-            if cdefbodynode.value.func.as_string() not in ATTRIB_NAMES:
+        if isinstance(cdef_body_node.value, Call):
+            if cdef_body_node.value.func.as_string() not in ATTRIB_NAMES:
                 continue
         else:
             continue
         targets = (
-            cdefbodynode.targets
-            if hasattr(cdefbodynode, "targets")
-            else [cdefbodynode.target]
+            cdef_body_node.targets
+            if hasattr(cdef_body_node, "targets")
+            else [cdef_body_node.target]
         )
         for target in targets:
-
             rhs_node = Unknown(
-                lineno=cdefbodynode.lineno,
-                col_offset=cdefbodynode.col_offset,
-                parent=cdefbodynode,
+                lineno=cdef_body_node.lineno,
+                col_offset=cdef_body_node.col_offset,
+                parent=cdef_body_node,
             )
-            node.locals[target.name] = [rhs_node]
-            node.instance_attrs[target.name] = [rhs_node]
+            if isinstance(target, AssignName):
+                # Could be a subscript if the code analysed is
+                # i = Optional[str] = ""
+                # See https://github.com/PyCQA/pylint/issues/4439
+                node.locals[target.name] = [rhs_node]
+                node.instance_attrs[target.name] = [rhs_node]
 
 
 AstroidManager().register_transform(
