@@ -16,9 +16,9 @@
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Vilnis Termanis <vilnis.termanis@iotics.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 doranid <ddandd@gmail.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
@@ -46,7 +46,6 @@ from astroid.exceptions import (
 )
 
 if sys.version_info >= (3, 8):
-    # pylint: disable=no-name-in-module
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -796,7 +795,7 @@ def match_mapping_assigned_stmts(
     is Uninferable.
     """
     return
-    yield  # pylint: disable=unreachable
+    yield
 
 
 nodes.MatchMapping.assigned_stmts = match_mapping_assigned_stmts
@@ -813,7 +812,7 @@ def match_star_assigned_stmts(
     is Uninferable.
     """
     return
-    yield  # pylint: disable=unreachable
+    yield
 
 
 nodes.MatchStar.assigned_stmts = match_star_assigned_stmts
